@@ -20,9 +20,9 @@
     where *red*, *green* and *blue* are floats in the range from 0.0 to 1.0.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 import wx
 
@@ -39,48 +39,49 @@ from color_editor \
 #---------------------------------------------------------------------------
 #  The wxPython ToolkitEditorFactory class.
 #---------------------------------------------------------------------------
+
+
 class ToolkitEditorFactory(BaseColorToolkitEditorFactory):
     """ wxPython editor factory for color editors.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Gets the wxPython color equivalent of the object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def to_wx_color ( self, editor, color=None ):
+    def to_wx_color(self, editor, color=None):
         """ Gets the wxPython color equivalent of the object trait.
         """
         if color is None:
             try:
-                color = getattr( editor.object, editor.name + '_' )
+                color = getattr(editor.object, editor.name + '_')
             except AttributeError:
-                color = getattr( editor.object, editor.name )
+                color = getattr(editor.object, editor.name)
         if isinstance(color, tuple):
-            return wx.Colour( int( color[0] * 255.0 ),
-                              int( color[1] * 255.0 ),
-                              int( color[2] * 255.0 ) )
+            return wx.Colour(int(color[0] * 255.0),
+                             int(color[1] * 255.0),
+                             int(color[2] * 255.0))
         return color
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Gets the application equivalent of a wxPython value:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def from_wx_color ( self, color ):
+    def from_wx_color(self, color):
         """ Gets the application equivalent of a wxPython value.
         """
-        return ( color.Red()   / 255.0,
-                 color.Green() / 255.0,
-                 color.Blue()  / 255.0 )
+        return (color.Red() / 255.0,
+                color.Green() / 255.0,
+                color.Blue() / 255.0)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns the text representation of a specified color value:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def str_color ( self, color ):
+    def str_color(self, color):
         """ Returns the text representation of a specified color value.
         """
-        if type( color ) in SequenceTypes:
-            return "(%d,%d,%d)" % ( int( color[0] * 255.0 ),
-                                    int( color[1] * 255.0 ),
-                                    int( color[2] * 255.0 ) )
+        if type(color) in SequenceTypes:
+            return "(%d,%d,%d)" % (int(color[0] * 255.0),
+                                   int(color[1] * 255.0),
+                                   int(color[2] * 255.0))
         return super(ToolkitEditorFactory, self).str_color(color)
-
